# Generated by Django 2.2.16 on 2020-09-14 16:55

# Django
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("fleetpings", "0001_initial"),
    ]

    operations = [
        migrations.AlterField(
            model_name="webhook",
            name="is_embedded",
            field=models.BooleanField(
                db_index=True,
                default=True,
                help_text=(
                    "Whether this webhook's ping is embedded or not. "
                    "(This setting only effects Discord webhooks.)"
                ),
            ),
        ),
    ]
