# Generated by Django 4.0.3 on 2022-04-16 22:23

# Django
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("fleetpings", "0008_auto_20210114_1733"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="webhook",
            name="is_embedded",
        ),
        migrations.RemoveField(
            model_name="webhook",
            name="type",
        ),
        migrations.AlterField(
            model_name="webhook",
            name="url",
            field=models.CharField(
                help_text="URL of this webhook, e.g. https://discord.com/api/webhooks/123456/abcdef",
                max_length=255,
                unique=True,
            ),
        ),
    ]
